import java.awt.Color;
import java.awt.Graphics2D;
//Documentacion de la clase.

/**
Clase Ball que es el modelo para las bolas del sistema.
@author Nicolas Olivos
*/

public class Ball extends PhysicsElement{
    private static int id=0;
    /**
    *  mass es la masa de la bola
    */
    private final double mass;
    private Vector2D pos_t;
    private Vector2D pos_tPlusDelta;
    private Vector2D speed_t;
    private Vector2D speed_tPlusDelta;
    /**
    *  view es la representacion grafica de la bola
    */
    private BallView view;

    private Ball(){
        this(1.0,new Vector2D(),new Vector2D());
    }

    /** 
    * Constructor Ball.  Inicializa una nueva bola.  
    * @param mass 	Masa de la bola
    * @param position 	Posicion inicial de la bola
    * @param speed  	Velocidad de la bola
    */
    public Ball(double mass, Vector2D position, Vector2D speed){
        super(id++);
        this.mass = mass;
        pos_t = position;
        speed_t = speed;
        view=new BallView(this,0.08);
    }
    
    public Vector2D getPosition() {
        return pos_t;
    }

    /** 
    * Calcula el siguiente estado de la bola.  
    * @param delta_t 	 Tiempo trascurrido
    * @return       noe
    */
    @Override
    public void computeNextState(double delta_t) {
        pos_tPlusDelta= pos_t.plus(speed_t.times(delta_t));
        speed_tPlusDelta=speed_t;
    }
    
    @Override
    public void updateState(){
        pos_t=pos_tPlusDelta;
        speed_t=speed_tPlusDelta;
    }
    
    @Override
    public void paintView(Graphics2D g){
        view.paint(g);
    }
    
    public void setColor(Color color){
        this.view.setColor(color);
    }
}
