import java.awt.Color;
import java.awt.Graphics2D;
import java.util.ArrayList;

public class Ball extends PhysicsElement implements Simulateable,Attachable {
    private static int id=0;
    private final double mass;
    private Vector2D pos_t;
    private Vector2D pos_tPlusDelta;
    private Vector2D speed_t;
    private Vector2D speed_tPlusDelta;
    private Vector2D acc_t;
    private Vector2D acc_tPlusDelta; 
    private ArrayList<Connector> con=null;
    private BallView view;

    private Ball(){
        this(1.0,new Vector2D(),new Vector2D());
    }
    
    public Ball(double mass, Vector2D position, Vector2D speed){
        super(id++);
        this.mass = mass;
        pos_t = position;
        speed_t = speed;
        view=new BallView(this,0.05);
        con = new ArrayList<>();
    }
    
    @Override
    public Vector2D getPosition() {
        return pos_t;
    }
    
    @Override
    public void computeNextState(double delta_t) {
        if (con.isEmpty()){
            pos_tPlusDelta= pos_t.plus(speed_t.times(delta_t));
            speed_tPlusDelta=speed_t;
        }
        else{
            acc_tPlusDelta = getNetForce().times(1/mass);
            pos_tPlusDelta= pos_t.plus(speed_t.times(delta_t)).plus(acc_tPlusDelta.times(delta_t*delta_t));
            speed_tPlusDelta=speed_t.plus(acc_tPlusDelta.times(delta_t));
        }
    }
    
    @Override
    public void updateState(){
        pos_t=pos_tPlusDelta;
        speed_t=speed_tPlusDelta;
        acc_t=acc_tPlusDelta;
    }
    
    public void setColor(Color color){
        this.view.setColor(color);
    }
    
    @Override
    public void paintView(Graphics2D g){
        view.paint(g);
    }

    @Override
    public void attach(Connector c) {
        con.add(c);
    }
    
    private Vector2D getNetForce(){
        Vector2D netForce=new Vector2D(0, 0);
        for (Connector e: con)
            netForce=netForce.plus(e.getForce(this));
        return netForce;
    }

    @Override
    public Vector2D getSpeed() {
        return this.speed_t;
    }    
}
