import java.awt.BasicStroke;
import java.awt.Color;
import java.awt.Graphics2D;
import java.awt.Stroke;
import java.awt.geom.AffineTransform;
import java.awt.geom.Path2D;


public class DashpotView {
    private static final double xPoints[]={0 ,0.5,0.5 ,  0.5,0.75,1, 0.25, 0.75, 0.75,  0.25};
    private static final double yPoints[]={0 ,0  ,0.02,-0.02,0   ,0,0.125,0.125,-0.125,-0.125};
    private static final Path2D.Double polyline = 
            new Path2D.Double(Path2D.WIND_EVEN_ODD,xPoints.length);
    private Dashpot dashpot;
    private Stroke stroke;
    
    
    static {
        for(int i=0;i<6;i++){
            if(i%2==0)
                polyline.moveTo (xPoints[i], yPoints[i]);
            else
                polyline.lineTo(xPoints[i], yPoints[i]);
        }
        
        polyline.moveTo (xPoints[6], yPoints[6]);
        for(int i=7;i<10;i++){
            polyline.lineTo (xPoints[i], yPoints[i]);
        }        
    }
    
    public DashpotView(Dashpot dash){
        dashpot=dash;
        stroke = new BasicStroke(0.01f);
    }
    
    public Vector2D getAendPosition() {
        return dashpot.getAendPosition();
    }
    
    public Vector2D getBendPosition() {
        return dashpot.getBendPosition();
    }

    void paint(Graphics2D g) {
        Vector2D a=getAendPosition();
        double ax = a.getX();
        double ay = a.getY();
        Vector2D v = getBendPosition().minus(a);
        double largo=v.module();
        AffineTransform at = AffineTransform.getTranslateInstance(ax, ay);
        at.rotate(v.getX(), v.getY());
        at.scale(v.module(),  largo);
        Path2D.Double shape2 = (Path2D.Double) at.createTransformedShape(polyline);
        g.setColor(Color.BLACK);
        g.setStroke(stroke);
        g.draw(shape2);
    }    
}
