import java.awt.BasicStroke;
import java.awt.Color;
import java.awt.Graphics2D;
import java.awt.Stroke;
import java.awt.geom.AffineTransform;
import java.awt.geom.Path2D;
/**
*@author Nicolas Olivos
*/
public class ElasticView {
    private static final double xPoints[]={0,1.0};
    private static final double yPoints[]={0,0};
    private static final Path2D.Double polyline = 
            new Path2D.Double(Path2D.WIND_EVEN_ODD,xPoints.length);
    private Stroke stroke;
    private Elastic elastic;

    static {
        polyline.moveTo (xPoints[0], yPoints[0]);
        polyline.lineTo(xPoints[1], yPoints[1]);
    }
    public ElasticView(Elastic elastic) {
        this.elastic = elastic;
        stroke = new BasicStroke(0.01f);
    }
    public Vector2D getAendPosition() {
        return elastic.getAendPosition();
    }
    public Vector2D getBendPosition() {
        return elastic.getBendPosition();
    }
    public void paint (Graphics2D g){
        Vector2D a=getAendPosition();
        double restLength = elastic.getRestLength();
        double ax = a.getX();
        double ay = a.getY();
        Vector2D v = getBendPosition().minus(a);
        AffineTransform at = AffineTransform.getTranslateInstance(ax, ay);
        at.rotate(v.getX(), v.getY());
        at.scale(v.module(),  restLength);
        Path2D.Double shape = (Path2D.Double) at.createTransformedShape(polyline);
        if (v.module() < restLength)
            g.setColor(Color.YELLOW);
        else if (v.module() > restLength)
            g.setColor(Color.RED);
        else
            g.setColor(Color.BLACK);
        g.setStroke(stroke);
        g.draw(shape);
    }
}