import java.awt.Graphics2D;

public class Spring extends PhysicsElement implements Connector{
    private static int id=0;  // Spring identification
    protected final double restLength;
    private final double stiffness;
    protected Attachable a_end, b_end;
    protected SpringView view;

    private Spring(){   // nobody can create a spring without state
        this(0,0);
    }
    
    public Spring(double restLength, double stiffness){
        super(id++);
        this.restLength = restLength;
        this.stiffness = stiffness;
        a_end = b_end = null;
        view = new SpringView(this);
    }
    
    @Override
    public void attachEnd (Attachable sa) {  // note: we attach a spring to a ball, 
        if(a_end==null)                             //       not the other way around.
            a_end = sa; 
        else if(b_end==null)
            b_end=sa;
        sa.attach(this);
    }
    
    private Vector2D getStrech() {
        Vector2D va=null,vb=null,amenosb,s;
        double factor,normaAmenosB;
        if (a_end==null||b_end==null)
            return new Vector2D(0.0,0.0);
        if (a_end!=null)
            va=a_end.getPosition();
        if (b_end!=null)
            vb=b_end.getPosition();
        if(va==null)
            return new Vector2D(0.0,0.0);
        amenosb=va.minus(vb);
        normaAmenosB=amenosb.module();
        factor=(normaAmenosB-this.restLength)/normaAmenosB;
        s=amenosb.times(factor);
        return s;
    }
    
    @Override
    public Vector2D getForce(Ball ball) {
        Vector2D force=getStrech().times(stiffness);
        return (ball==a_end)?force.times(-1):force;
    }
    
    public Vector2D getAendPosition() {
        return a_end.getPosition();
    }
    
    public Vector2D getBendPosition() {
        return b_end.getPosition();
    }
    
    public double getRestLength() {
        return restLength;
    }
    
    @Override
    public void paintView (Graphics2D g) {
        view.paint(g);  // update this spring's view in Model-View-Controller design pattern     
    }
}